﻿-- MySQL Workbench Forward Engineering

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES,NO_ZERO_IN_DATE,NO_ZERO_DATE,ERROR_FOR_DIVISION_BY_ZERO,NO_ENGINE_SUBSTITUTION';
SET AUTOCOMMIT = 0;

START TRANSACTION;

-- -----------------------------------------------------
-- Schema mydb
-- -----------------------------------------------------
-- -----------------------------------------------------
-- Schema test-exec
-- -----------------------------------------------------

-- -----------------------------------------------------
-- Schema test-exec
-- -----------------------------------------------------
CREATE SCHEMA IF NOT EXISTS `test-exec` DEFAULT CHARACTER SET latin1 COLLATE latin1_general_ci ;

USE `test-exec` ;

-- -----------------------------------------------------
-- Table `test-exec`.`data_table`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`data_table` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(300) NOT NULL,
  `is_deleted` TINYINT(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`))
ENGINE = InnoDB
AUTO_INCREMENT = 9
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`column`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`column` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(300) NULL DEFAULT NULL,
  `is_deleted` TINYINT(1) NULL DEFAULT NULL,
  `data_table_id` INT(11) NOT NULL,
  `data_type` INT(1) NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_column_data_table1_idx` (`data_table_id` ASC),
  CONSTRAINT `fk_column_data_table1`
    FOREIGN KEY (`data_table_id`)
    REFERENCES `test-exec`.`data_table` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 39
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`row`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`row` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(300) NOT NULL,
  `is_deleted` TINYINT(1) NULL DEFAULT NULL,
  `data_table_id` INT(11) NOT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_row_data_table1_idx` (`data_table_id` ASC),
  CONSTRAINT `fk_row_data_table1`
    FOREIGN KEY (`data_table_id`)
    REFERENCES `test-exec`.`data_table` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 196
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`data`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`data` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `value` VARCHAR(300) NULL DEFAULT NULL,
  `data_type` INT(1) NULL DEFAULT NULL,
  `row_id` INT(11) NOT NULL,
  `column_id` INT(11) NOT NULL,
  `timestamp` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `data_table_id` INT(11) NOT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_data_row1_idx` (`row_id` ASC),
  INDEX `fk_data_column1_idx` (`column_id` ASC),
  CONSTRAINT `fk_data_column1`
    FOREIGN KEY (`column_id`)
    REFERENCES `test-exec`.`column` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_data_row1`
    FOREIGN KEY (`row_id`)
    REFERENCES `test-exec`.`row` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 1179
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`method`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`method` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(300) NOT NULL,
  `description` TEXT NULL DEFAULT NULL,
  `revision` INT(11) NOT NULL,
  `is_deleted` TINYINT(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`))
ENGINE = InnoDB
AUTO_INCREMENT = 33
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`method_parameter`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`method_parameter` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `method_id` INT(11) NOT NULL,
  `name` VARCHAR(300) NOT NULL,
  `description` TEXT NULL DEFAULT NULL,
  `default_value` VARCHAR(300) NOT NULL,
  `data_type` INT(1) NOT NULL,
  `is_optional` TINYINT(1) NOT NULL DEFAULT '0',
  `min_value` VARCHAR(300) NULL DEFAULT NULL,
  `max_value` VARCHAR(300) NULL DEFAULT NULL,
  `unit_of_measure` VARCHAR(45) NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_test_parameter_test1_idx` (`method_id` ASC),
  CONSTRAINT `fk_test_parameter_test1`
    FOREIGN KEY (`method_id`)
    REFERENCES `test-exec`.`method` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 227
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`model`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`model` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(300) NOT NULL,
  `description` TEXT NULL DEFAULT NULL,
  `revision` INT(11) NOT NULL DEFAULT '0',
  `create_date` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `is_deleted` TINYINT(1) NOT NULL DEFAULT '0',
  `is_state` TINYINT(1) NOT NULL DEFAULT '0',
  `options` TEXT NULL DEFAULT NULL,
  PRIMARY KEY (`id`))
ENGINE = InnoDB
AUTO_INCREMENT = 5
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`step`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`step` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `step_id_parent` INT(11) NULL DEFAULT NULL,
  `model_id` INT(11) NOT NULL,
  `method_id` INT(11) NOT NULL,
  `name` VARCHAR(200) NOT NULL COMMENT 'Name of the step',
  `position` INT(11) NOT NULL DEFAULT '0' COMMENT 'The sort position on the step sequence.',
  `report_errors` TINYINT(1) NOT NULL DEFAULT '0',
  `report_results` TINYINT(1) NOT NULL DEFAULT '0',
  `max_attempts` INT(11) NOT NULL DEFAULT '1' COMMENT 'Maximum number of attempts for the step to pass',
  `timeout` BIGINT(20) NULL DEFAULT '0' COMMENT 'Response timeout value',
  `discard_on_fail` TINYINT(1) NOT NULL DEFAULT '0',
  `is_enabled` TINYINT(1) NOT NULL DEFAULT '1',
  `is_deleted` TINYINT(1) NOT NULL DEFAULT '0',
  `is_user_changeable` TINYINT(1) NOT NULL DEFAULT '1',
  `group_id` INT(11) NULL DEFAULT NULL,
  `state` VARCHAR(200) NULL DEFAULT NULL,
  `run_until` TINYINT(1) NOT NULL DEFAULT '0',
  `run_until_cond` TINYINT(1) NOT NULL DEFAULT '0',
  `exec_substeps` TINYINT(1) NOT NULL DEFAULT '0',
  `exec_substeps_cond` TINYINT(1) NOT NULL DEFAULT '0',
  `use_substeps_result` TINYINT(1) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  INDEX `fk_step_model1_idx` (`model_id` ASC),
  INDEX `fk_step_method1_idx` (`method_id` ASC),
  INDEX `fk_step_step1_idx` (`step_id_parent` ASC),
  CONSTRAINT `fk_step_method1`
    FOREIGN KEY (`method_id`)
    REFERENCES `test-exec`.`method` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_step_model1`
    FOREIGN KEY (`model_id`)
    REFERENCES `test-exec`.`model` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_step_step1`
    FOREIGN KEY (`step_id_parent`)
    REFERENCES `test-exec`.`step` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 2750
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`state_relation`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`state_relation` (
  `model_id` INT(11) NOT NULL,
  `step_id` INT(11) NOT NULL,
  PRIMARY KEY (`model_id`, `step_id`),
  INDEX `fk_step_relation_model1_idx` (`model_id` ASC),
  INDEX `fk_step_relation_step1_idx` (`step_id` ASC),
  CONSTRAINT `fk_step_relation_model1`
    FOREIGN KEY (`model_id`)
    REFERENCES `test-exec`.`model` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_step_relation_step1`
    FOREIGN KEY (`step_id`)
    REFERENCES `test-exec`.`step` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`status`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`status` (
  `idstatus` INT(11) NOT NULL AUTO_INCREMENT,
  `label` VARCHAR(300) NULL DEFAULT NULL,
  PRIMARY KEY (`idstatus`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`step_parameter_value`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`step_parameter_value` (
  `step_id` INT(11) NOT NULL,
  `method_parameter_id` INT(11) NOT NULL,
  `value` VARCHAR(300) NOT NULL,
  `is_user_changeable` TINYINT(1) NOT NULL DEFAULT '1',
  `is_user_visible` TINYINT(1) NOT NULL DEFAULT '1',
  `data_table_source_id` INT(11) NOT NULL,
  `data_id` INT(11) NULL DEFAULT NULL,
  `data_table_id` INT(11) NULL DEFAULT NULL,
  PRIMARY KEY (`step_id`, `method_parameter_id`),
  INDEX `fk_step_has_method_parameter_method_parameter1_idx` (`method_parameter_id` ASC),
  INDEX `fk_step_has_method_parameter_step1_idx` (`step_id` ASC),
  INDEX `fk_step_parameter_value_data1_idx` (`data_id` ASC),
  INDEX `fk_step_parameter_value_data_table1_idx` (`data_table_id` ASC),
  CONSTRAINT `fk_step_has_method_parameter_method_parameter1`
    FOREIGN KEY (`method_parameter_id`)
    REFERENCES `test-exec`.`method_parameter` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_step_has_method_parameter_step1`
    FOREIGN KEY (`step_id`)
    REFERENCES `test-exec`.`step` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_step_parameter_value_data1`
    FOREIGN KEY (`data_id`)
    REFERENCES `test-exec`.`data` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_step_parameter_value_data_table1`
    FOREIGN KEY (`data_table_id`)
    REFERENCES `test-exec`.`data_table` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`test_run`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`test_run` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `model_id` INT(11) NOT NULL,
  `nest` TINYINT(1) NOT NULL DEFAULT '1',
  `test_start` DATETIME NOT NULL,
  `barcode` VARCHAR(300) NULL DEFAULT NULL,
  `test_end` DATETIME NULL DEFAULT NULL,
  `result` VARCHAR(1) NULL DEFAULT NULL,
  `error_text` TEXT NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_test_run_model1_idx` (`model_id` ASC),
  CONSTRAINT `fk_test_run_model1`
    FOREIGN KEY (`model_id`)
    REFERENCES `test-exec`.`model` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`step_result`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`step_result` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `step_id` INT(11) NOT NULL,
  `test_run_id` INT(11) NOT NULL COMMENT 'Parent test run',
  `result` VARCHAR(1) NOT NULL COMMENT 'Step result where P is passed and F is Failed',
  `error_text` VARCHAR(300) NULL DEFAULT NULL COMMENT 'If the result fails put error text here.',
  `start_time` DATETIME NOT NULL,
  `duration` DOUBLE NOT NULL COMMENT 'Duration in seconds',
  `attempts` INT(11) NOT NULL DEFAULT '1' COMMENT 'Number of attempts used for step execution',
  `details` VARCHAR(300) NULL DEFAULT NULL COMMENT 'Any addional details to be logged for the step run',
  PRIMARY KEY (`id`),
  INDEX `fk_step_result_step1_idx` (`step_id` ASC),
  INDEX `fk_step_result_test_run1_idx` (`test_run_id` ASC),
  CONSTRAINT `fk_step_result_step1`
    FOREIGN KEY (`step_id`)
    REFERENCES `test-exec`.`step` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_step_result_test_run1`
    FOREIGN KEY (`test_run_id`)
    REFERENCES `test-exec`.`test_run` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`step_variable`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`step_variable` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `step_result_id` INT(11) NOT NULL,
  `name` VARCHAR(300) NOT NULL COMMENT 'Name of the output variable',
  `unit_of_measure` VARCHAR(45) NULL DEFAULT NULL COMMENT 'Unit of measure of the output variable',
  `data_type` INT(1) NOT NULL COMMENT 'Format data type',
  `value` VARCHAR(300) NOT NULL,
  PRIMARY KEY (`id`),
  INDEX `fk_output_step_result1_idx` (`step_result_id` ASC),
  CONSTRAINT `fk_output_step_result1`
    FOREIGN KEY (`step_result_id`)
    REFERENCES `test-exec`.`step_result` (`id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec`.`user`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec`.`user` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(300) NOT NULL COMMENT 'Full name of the user',
  `email` VARCHAR(300) NOT NULL COMMENT 'Company email',
  `access_level` INT(2) NOT NULL DEFAULT '2' COMMENT 'System access levels:\\n1 : Admin Access\\n2: Operator Access\\n99: Super User',
  `password` VARCHAR(300) NOT NULL COMMENT 'Encrypted password',
  PRIMARY KEY (`id`),
  UNIQUE INDEX `email_UNIQUE` (`email` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;

COMMIT; 

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;