﻿-- use children result is only allowed when execute_children_condition != ALWAYS (0)
UPDATE `step`
SET `use_children_result` = 0
WHERE `execute_children_cond` = 0;

-- update name and position in state main children
UPDATE `step` to_update
JOIN (SELECT id as script_id, is_state as in_script_state FROM script) sc
ON sc.script_id = to_update.script_id AND sc.in_script_state <> 0
JOIN (SELECT id as main_id FROM step WHERE step_id_parent IS NULL) main
ON main.main_id = to_update.step_id_parent
SET to_update.name = CASE WHEN to_update.name LIKE '%enter%' THEN 'Enter'
                            WHEN to_update.name LIKE '%leave%' THEN 'Leave'
                            ELSE '?'
                    END,
to_update.position = CASE WHEN to_update.name LIKE '%enter%' THEN '0'
                                WHEN to_update.name LIKE '%leave%' THEN '1'
                                ELSE '2'
                        END;

-- assign position 0 to all main steps
UPDATE `step` to_update 
SET to_update.`position` = 0
WHERE to_update.`step_id_parent` IS NULL;

-- assign the step sibling position continuously (e.g. {0, 1, 2, 18} for a group of siblings should end up like {0, 1, 2, 3})
-- for this, it is necessary to group the steps by its step_parent_id (having it not null), and order each group by position, id (in that order, id column will help on duplicated positions)
UPDATE `step` to_update
JOIN (SELECT Id,
        CASE step_id_parent 
        WHEN @curType THEN @curRow := @curRow + 1 
        ELSE @curRow := 0 
        END AS created_position, 
        @curType := step_id_parent as step_id_parent 
        FROM (SELECT Id, step_id_parent FROM `step` WHERE step_id_parent IS NOT NULL ORDER BY step_id_parent, position, id) c 
        JOIN (SELECT @curRow := 0, @curType := 0) r) position_relations 
ON to_update.Id = position_relations.Id
SET position = created_position;

-- delete all steps that are main children for state script and are not 'enter' and 'leave' steps (position 0 and position 1)
DELETE `step` FROM `step`
LEFT JOIN (SELECT `id` as script_id, `is_state` as in_script_state FROM `script`) sc
ON sc.script_id = `step`.script_id
LEFT JOIN (SELECT id as main_id FROM `step` WHERE `step_id_parent` IS NULL) main
ON main.main_id = `step`.step_id_parent
WHERE sc.`in_script_state` <> 0 AND `step`.`step_id_parent` = main.main_id AND `step`.`position` NOT IN (0, 1);

-- update for all main, enter and leave steps the default flag and condition values
UPDATE `step` to_update
LEFT JOIN (SELECT `id` as script_id, `is_state` as in_script_state FROM `script`) sc
ON sc.script_id = to_update.script_id
LEFT JOIN (SELECT id as main_id FROM `step` WHERE `step_id_parent` IS NULL) main
ON main.main_id = to_update.step_id_parent
SET to_update.`is_enabled`= 1,
    to_update.`report_results` = 1,
    to_update.`execute_children_cond` = 0,
    to_update.`use_children_result` = 0,
    to_update.`discard_group_on_fail`= 0,
    to_update.`run_until_passed` = 0,
    to_update.`max_attempts` = 1,
    to_update.`timeout` = 0
WHERE to_update.step_id_parent IS NULL OR (sc.`in_script_state` <> 0 AND to_update.`step_id_parent` = main.main_id);