﻿ -- MySQL Workbench Forward Engineering
SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='ONLY_FULL_GROUP_BY,STRICT_TRANS_TABLES,NO_ZERO_IN_DATE,NO_ZERO_DATE,ERROR_FOR_DIVISION_BY_ZERO,NO_ENGINE_SUBSTITUTION';

SET AUTOCOMMIT = 0;

START TRANSACTION;

-- -----------------------------------------------------
-- Schema test-exec-result-backup
-- -----------------------------------------------------

DROP DATABASE IF EXISTS `test-exec-result-backup`;

-- -----------------------------------------------------
-- Schema test-exec-result-backup
-- -----------------------------------------------------
CREATE SCHEMA IF NOT EXISTS `test-exec-result-backup` DEFAULT CHARACTER SET latin1 COLLATE latin1_general_ci ;

-- -----------------------------------------------------
-- Table `test-exec-result-backup`.`tester`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec-result-backup`.`tester` (
    `Id` INT(11) NOT NULL AUTO_INCREMENT,
    `Name` VARCHAR(100) NOT NULL,
    `Serial_no` VARCHAR(50) NOT NULL,
    `Prod_line` VARCHAR(20) NOT NULL,
    PRIMARY KEY (`Id`))
ENGINE = InnoDB
AUTO_INCREMENT = 11
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec-result-backup`.`test_run`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec-result-backup`.`test_run` (
    `Id` INT(11) NOT NULL AUTO_INCREMENT,
    `Tester_Id` INT(11) NULL DEFAULT NULL,
    `Script` VARCHAR(300) NOT NULL,
    `Test_start` DATETIME NOT NULL,
    `Result` TINYINT(1) NOT NULL COMMENT 'Result where True is Passed and False is Failed',
    `Is_scrap` TINYINT(1) NOT NULL DEFAULT '0',
    `Nest` TINYINT(1) NULL DEFAULT '0',
    `Test_end` DATETIME NULL DEFAULT NULL,
    `Duration` DOUBLE NULL DEFAULT NULL,
    `Barcode` VARCHAR(300) NULL DEFAULT NULL,
    `Error_text` VARCHAR(1000) NULL DEFAULT NULL,
    PRIMARY KEY (`Id`),
    INDEX `fk_test_run_machine2_idx` (`Tester_Id` ASC),
    CONSTRAINT `fk_test_run_machine2`
    FOREIGN KEY (`Tester_Id`)
    REFERENCES `test-exec-result-backup`.`tester` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 838
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;


-- -----------------------------------------------------
-- Table `test-exec-result-backup`.`step_result`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec-result-backup`.`step_result` (
    `Id` INT(11) NOT NULL AUTO_INCREMENT,
    `Test_run_id` INT(11) NOT NULL COMMENT 'Parent test run',
    `Step` VARCHAR(200) NOT NULL,
    `Method` VARCHAR(300) NOT NULL,
    `Start_time` DATETIME NOT NULL,
    `Duration` DOUBLE NOT NULL COMMENT 'Duration in seconds',
    `Attempts` INT(11) NOT NULL DEFAULT '1' COMMENT 'Number of attempts used for step execution',
    `Result` TINYINT(1) NOT NULL COMMENT 'Step result where True is Passed and False is Failed',
    `Details` VARCHAR(1000) NULL DEFAULT NULL COMMENT 'Any addional details to be logged for the step run',
    `State` VARCHAR(45) NULL DEFAULT NULL,
    PRIMARY KEY (`Id`),
    INDEX `fk_step_result_test_run1_idx` (`Test_run_id` ASC),
    CONSTRAINT `fk_step_result_test_run1`
    FOREIGN KEY (`Test_run_id`)
    REFERENCES `test-exec-result-backup`.`test_run` (`Id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 74796
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;

-- -----------------------------------------------------
-- Table `test-exec-result-backup`.`user`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `test-exec-result-backup`.`user` (
    `id` INT(11) NOT NULL AUTO_INCREMENT,
    `name` VARCHAR(300) NOT NULL,
    `email` VARCHAR(300) NOT NULL,
    `access_level` INT(1) NOT NULL,
    `password` VARCHAR(300) NOT NULL,
    PRIMARY KEY (`id`))
ENGINE = InnoDB
AUTO_INCREMENT = 24
DEFAULT CHARACTER SET = latin1
COLLATE = latin1_general_ci;

COMMIT; 

START TRANSACTION;

-- -----------------------------------------------------
-- Insert backup data into DB
-- -----------------------------------------------------

INSERT INTO `test-exec-result-backup`.`tester` (`Id`, `Name`, `Serial_no`, `Prod_line`) VALUES (1, 'Local', 'N/A', 'N/A');

INSERT INTO `test-exec-result-backup`.`test_run` (`Id`,     `Tester_Id`, `Script`,      `Test_start`,  `Result`,                                         `Is_scrap`, `Nest`,  `Test_end`,  `Duration`,         `Barcode`,  `Error_text`)
                                SELECT tr.`id`,      1,  tr_model.name, tr.test_start, case when result LIKE 'P' then '1' else '0' end, '0',         tr.nest, tr.test_end, sr_models.duration, tr.barcode, tr.error_text
                                FROM `test_run` tr
                                INNER JOIN `model` tr_model
                                ON tr.model_id = tr_model.id
                                LEFT JOIN (SELECT main_steps_results.tr_id as tr_id, models.id as model_id, models.name as model, main_steps_results.duration as duration FROM `model` models
                                    JOIN (SELECT  s.model_id as model_id, sr.test_run_id as tr_id, sr.duration FROM `step_result` sr
           		                        LEFT JOIN `step` s
           		                        ON sr.step_id = s.id
           		                        WHERE s.step_id_parent IS NULL) main_steps_results
                                    ON main_steps_results.model_id = models.id) sr_models
                                ON tr.id = sr_models.tr_id;


INSERT INTO `test-exec-result-backup`.`step_result` (`Id`, `Test_run_id`, `Step`, `Method`, `Start_time`, `Duration`, `Attempts`, `Result`, `Details`, `State`)
SELECT sr.id, sr.test_run_id, s.name as step_name, m.name, sr.start_time, sr.duration, sr.attempts, case when sr.result LIKE 'P' then '1' else '0' end, sr.details, s_relations.model FROM `step_result` sr
JOIN `step` s
ON sr.step_id = s.id
JOIN `method` m
ON s.method_id = m.id
LEFT JOIN (
    SELECT s.id as step_id, m.name as model FROM `state_relation` states
    JOIN `step` s
    ON states.step_id = s.id
    JOIN `model` m
    ON states.model_id = m.id) s_relations
ON s.id = s_relations.step_id;

INSERT INTO `test-exec-result-backup`.`user` (`id`, `name`, `email`, `access_level`, `password`)
SELECT `id`, `name`, `email`, `access_level`, `password` FROM `user`;

COMMIT; 

START TRANSACTION;

-- -----------------------------------------------------
-- Delete result tables in server
-- -----------------------------------------------------

DROP TABLE IF EXISTS `test_run` ;
                                    
DROP TABLE IF EXISTS `step_variable` ;
                                    
DROP TABLE IF EXISTS `step_result` ;
                                    
COMMIT; 
                                    
SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;